@@ -155,7 +155,7 @@ func main() {
 		srv := &http.Server{Addr: config.InternalAddr, Handler: router}
 
 		g.Add(srv.ListenAndServe, func(err error) {
-			if err == http.ErrServerClosed {
+			if errors.Is(err, http.ErrServerClosed) {
 				level.Warn(logger).Log("msg", "internal server closed unexpectedly")
 				return
 			}
@@ -507,7 +507,7 @@ func (c *controller) sync() {
 
 	c.populate(hashrings, statefulsets)
 
-	if err := c.saveHashring(hashrings); err != nil {
+	if err := c.saveHashring(hashrings, cm); err != nil {
 		c.reconcileErrors.WithLabelValues(save).Inc()
 		level.Error(c.logger).Log("msg", "failed to save hashrings")
 	}
@@ -537,7 +537,7 @@ func (c *controller) populate(hashrings []receive.HashringConfig, statefulsets m
 	}
 }
 
-func (c *controller) saveHashring(hashring []receive.HashringConfig) error {
+func (c *controller) saveHashring(hashring []receive.HashringConfig, orgCM *corev1.ConfigMap) error {
 	buf, err := json.Marshal(hashring)
 	if err != nil {
 		return err
@@ -547,6 +547,14 @@ func (c *controller) saveHashring(hashring []receive.HashringConfig) error {
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      c.options.configMapGeneratedName,
 			Namespace: c.options.namespace,
+			OwnerReferences: []metav1.OwnerReference{
+				{
+					APIVersion: "v1",
+					Kind:       "ConfigMap",
+					Name:       orgCM.GetName(),
+					UID:        orgCM.GetUID(),
+				},
+			},
 		},
 		Data: map[string]string{
 			c.options.fileName: string(buf),
@@ -595,9 +603,7 @@ func hashAsMetricValue(data []byte) float64 {
 	sum := md5.Sum(data) //nolint:gosec
 	// We only want 48 bits as a float64 only has a 53 bit mantissa.
 	smallSum := sum[0:6]
-
-	var bytes = make([]byte, 8)
-
+	bytes := make([]byte, 8)
 	copy(bytes, smallSum)
 
 	return float64(binary.LittleEndian.Uint64(bytes))
